@@ -1,5 +1,26 @@
 #!/bin/sh
 
+#
+# Canola Cleanup
+# Copyright (C) 2008 Instituto Nokia de Tecnologia
+# Author: Gustavo Barbieri <gustavo.barbieri@openbossa.org>
+#         Eduardo Lima (Etrunko) <eduardo.lima@indt.org.br>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+
 APT_GET="apt-get -y --force-yes -q"
 DPKG="dpkg --abort-after 999999"
 BASE_PACKAGES="\
@@ -23,7 +44,11 @@ EXTRA_PACKAGES="\
  expedite \
  python-efl-core-demo \
  python-efl-core \
- ogg-support-lms"
+ ogg-support-lms \
+ canola2-theme-deepblue \
+ canola2-theme-flatred \
+ canola2-theme-flatblack \
+ canola2-youtube-plugin"
 
 
 CLEAN_PATHS="\
